"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@testing-library/react");
const SearchBar_1 = require("./SearchBar");
describe('SearchBar', () => {
    const mockOnSearch = jest.fn();
    const defaultProps = {
        groupFilters: [{ label: 'All', value: 'all' }],
        filterFacets: [],
        onSearch: mockOnSearch,
        searchTitle: 'Search',
        placeholder: 'Search',
    };
    afterEach(() => {
        jest.clearAllMocks();
    });
    it('renders', () => {
        const { getByLabelText } = (0, react_1.render)((0, jsx_runtime_1.jsx)(SearchBar_1.default, { ...defaultProps }));
        expect(getByLabelText(defaultProps.searchTitle)).toBeInTheDocument();
    });
    it('initializes with correct initial state', () => {
        const { getByLabelText } = (0, react_1.render)((0, jsx_runtime_1.jsx)(SearchBar_1.default, { ...defaultProps }));
        const searchInput = getByLabelText(defaultProps.searchTitle);
        expect(searchInput.value).toBe('');
        expect(searchInput.placeholder).toBe(defaultProps.placeholder);
    });
    it('calls onSearch with the correct searchParams after user input', async () => {
        jest.useFakeTimers();
        const { getByLabelText } = (0, react_1.render)((0, jsx_runtime_1.jsx)(SearchBar_1.default, { ...defaultProps }));
        const searchInput = getByLabelText(defaultProps.searchTitle);
        react_1.fireEvent.change(searchInput, { target: { value: 'test' } });
        (0, react_1.act)(() => {
            jest.advanceTimersByTime(400);
        });
        await (0, react_1.waitFor)(() => expect(mockOnSearch).toHaveBeenCalledTimes(2));
        expect(mockOnSearch).toHaveBeenCalledWith({
            selectedGroupFilter: defaultProps.groupFilters[0].value,
            searchValue: 'test',
            selectedFilterFacets: [],
        });
        jest.useRealTimers();
    });
    it('debounces search input', async () => {
        jest.useFakeTimers();
        const { getByLabelText } = (0, react_1.render)((0, jsx_runtime_1.jsx)(SearchBar_1.default, { ...defaultProps }));
        const searchInput = getByLabelText(defaultProps.searchTitle);
        react_1.fireEvent.change(searchInput, { target: { value: 't' } });
        react_1.fireEvent.change(searchInput, { target: { value: 'te' } });
        react_1.fireEvent.change(searchInput, { target: { value: 'tes' } });
        react_1.fireEvent.change(searchInput, { target: { value: 'test' } });
        (0, react_1.act)(() => {
            jest.advanceTimersByTime(400);
        });
        await (0, react_1.waitFor)(() => expect(mockOnSearch).toHaveBeenCalledTimes(2));
        expect(mockOnSearch).toHaveBeenCalledWith({
            selectedGroupFilter: defaultProps.groupFilters[0].value,
            searchValue: 'test',
            selectedFilterFacets: [],
        });
        jest.useRealTimers();
    });
});
//# sourceMappingURL=Searchbar.spec.js.map